==> zio-aws-macie2_3-5.17.124.3-sources.jar: zio/aws/macie2/model/UpdateFindingsFilterRequest.scala <==
package zio.aws.macie2.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.{__integer, __string}
import scala.jdk.CollectionConverters.*
final case class UpdateFindingsFilterRequest(
    action: Option[zio.aws.macie2.model.FindingsFilterAction] = None,
    description: Option[__string] = None,
    findingCriteria: Option[zio.aws.macie2.model.FindingCriteria] = None,
    id: __string,
    name: Option[__string] = None,
    position: Option[__integer] = None,
    clientToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest = {
    import UpdateFindingsFilterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
      .builder()
      .optionallyWith(action.map(value => value.unwrap))(_.action)
      .optionallyWith(
        description.map(value => __string.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(findingCriteria.map(value => value.buildAwsValue()))(
        _.findingCriteria
      )
      .id(__string.unwrap(id): java.lang.String)
      .optionallyWith(
        name.map(value => __string.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(position.map(value => __integer.unwrap(value): Integer))(
        _.position
      )
      .optionallyWith(
        clientToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.clientToken)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateFindingsFilterRequest.ReadOnly =
    zio.aws.macie2.model.UpdateFindingsFilterRequest.wrap(buildAwsValue())
}
object UpdateFindingsFilterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateFindingsFilterRequest =
      zio.aws.macie2.model.UpdateFindingsFilterRequest(
        action.map(value => value),
        description.map(value => value),
        findingCriteria.map(value => value.asEditable),
        id,
        name.map(value => value),
        position.map(value => value),
        clientToken.map(value => value)
      )
    def action: Option[zio.aws.macie2.model.FindingsFilterAction]
    def description: Option[__string]
    def findingCriteria: Option[zio.aws.macie2.model.FindingCriteria.ReadOnly]
    def id: __string
    def name: Option[__string]
    def position: Option[__integer]
    def clientToken: Option[__string]
    def getAction
        : ZIO[Any, AwsError, zio.aws.macie2.model.FindingsFilterAction] =
      AwsError.unwrapOptionField("action", action)
    def getDescription: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("description", description)
    def getFindingCriteria
        : ZIO[Any, AwsError, zio.aws.macie2.model.FindingCriteria.ReadOnly] =
      AwsError.unwrapOptionField("findingCriteria", findingCriteria)
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
    def getName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("name", name)
    def getPosition: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("position", position)
    def getClientToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clientToken", clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
  ) extends zio.aws.macie2.model.UpdateFindingsFilterRequest.ReadOnly {
    override val action: Option[zio.aws.macie2.model.FindingsFilterAction] =
      scala
        .Option(impl.action())
        .map(value => zio.aws.macie2.model.FindingsFilterAction.wrap(value))
    override val description: Option[__string] = scala
      .Option(impl.description())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val findingCriteria
        : Option[zio.aws.macie2.model.FindingCriteria.ReadOnly] = scala
      .Option(impl.findingCriteria())
      .map(value => zio.aws.macie2.model.FindingCriteria.wrap(value))
    override val id: __string =
      zio.aws.macie2.model.primitives.__string(impl.id())
    override val name: Option[__string] = scala
      .Option(impl.name())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val position: Option[__integer] = scala
      .Option(impl.position())
      .map(value => zio.aws.macie2.model.primitives.__integer(value))
    override val clientToken: Option[__string] = scala
      .Option(impl.clientToken())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
  ): zio.aws.macie2.model.UpdateFindingsFilterRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-macie2_3-5.17.155.2-sources.jar: zio/aws/macie2/model/UpdateFindingsFilterRequest.scala <==
package zio.aws.macie2.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.{__integer, __string}
import scala.jdk.CollectionConverters.*
final case class UpdateFindingsFilterRequest(
    action: Option[zio.aws.macie2.model.FindingsFilterAction] = None,
    description: Option[__string] = None,
    findingCriteria: Option[zio.aws.macie2.model.FindingCriteria] = None,
    id: __string,
    name: Option[__string] = None,
    position: Option[__integer] = None,
    clientToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest = {
    import UpdateFindingsFilterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
      .builder()
      .optionallyWith(action.map(value => value.unwrap))(_.action)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(findingCriteria.map(value => value.buildAwsValue()))(
        _.findingCriteria
      )
      .id(id: java.lang.String)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(position.map(value => value: Integer))(_.position)
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateFindingsFilterRequest.ReadOnly =
    zio.aws.macie2.model.UpdateFindingsFilterRequest.wrap(buildAwsValue())
}
object UpdateFindingsFilterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateFindingsFilterRequest =
      zio.aws.macie2.model.UpdateFindingsFilterRequest(
        action.map(value => value),
        description.map(value => value),
        findingCriteria.map(value => value.asEditable),
        id,
        name.map(value => value),
        position.map(value => value),
        clientToken.map(value => value)
      )
    def action: Option[zio.aws.macie2.model.FindingsFilterAction]
    def description: Option[__string]
    def findingCriteria: Option[zio.aws.macie2.model.FindingCriteria.ReadOnly]
    def id: __string
    def name: Option[__string]
    def position: Option[__integer]
    def clientToken: Option[__string]
    def getAction
        : ZIO[Any, AwsError, zio.aws.macie2.model.FindingsFilterAction] =
      AwsError.unwrapOptionField("action", action)
    def getDescription: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("description", description)
    def getFindingCriteria
        : ZIO[Any, AwsError, zio.aws.macie2.model.FindingCriteria.ReadOnly] =
      AwsError.unwrapOptionField("findingCriteria", findingCriteria)
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
    def getName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("name", name)
    def getPosition: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("position", position)
    def getClientToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clientToken", clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
  ) extends zio.aws.macie2.model.UpdateFindingsFilterRequest.ReadOnly {
    override val action: Option[zio.aws.macie2.model.FindingsFilterAction] =
      scala
        .Option(impl.action())
        .map(value => zio.aws.macie2.model.FindingsFilterAction.wrap(value))
    override val description: Option[__string] =
      scala.Option(impl.description()).map(value => value: __string)
    override val findingCriteria
        : Option[zio.aws.macie2.model.FindingCriteria.ReadOnly] = scala
      .Option(impl.findingCriteria())
      .map(value => zio.aws.macie2.model.FindingCriteria.wrap(value))
    override val id: __string = impl.id(): __string
    override val name: Option[__string] =
      scala.Option(impl.name()).map(value => value: __string)
    override val position: Option[__integer] =
      scala.Option(impl.position()).map(value => value: __integer)
    override val clientToken: Option[__string] =
      scala.Option(impl.clientToken()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateFindingsFilterRequest
  ): zio.aws.macie2.model.UpdateFindingsFilterRequest.ReadOnly = new Wrapper(
    impl
  )
}
